import { AfterViewInit, Component, ViewChild, ChangeDetectionStrategy, ChangeDetectorRef } from '@angular/core';
import { ContinentsBirthRateItem, ContinentsBirthRate } from './ContinentsBirthRate';
import { IgxLegendComponent, IgxDataChartComponent, IgxCategoryXAxisComponent, IgxNumericYAxisComponent,
    IgxStackedLineSeriesComponent, IgxStackedFragmentSeriesComponent, IgxStackedSeriesCreatedEventArgs } from 'igniteui-angular-charts';
import { Random } from 'igniteui-angular-core';


@Component({
    selector: "app-root",
    styleUrls: ["./app.component.scss"],
    templateUrl: "./app.component.html",
    changeDetection: ChangeDetectionStrategy.OnPush
})
export class AppComponent {

    public data: any[];

    public constructor(private _detector: ChangeDetectorRef) {
        this.initData();
    }

    public initData(){
        const dataItems: any[] = [];

        const nan = Number.NaN;

        // some data items with not a numbers
        dataItems.push({ Label: "Item 0",  Value1: 0.2, Value2: 0.1, Value3: 0.4 });
        dataItems.push({ Label: "Item 1",  Value1: 0.1, Value2: 0.3, Value3: 0.2 });
        dataItems.push({ Label: "Item 2",  Value1: 0.2, Value2: 0.1, Value3: 0.4 });
        dataItems.push({ Label: "Item 3",  Value1: nan, Value2: nan, Value3: nan });
        dataItems.push({ Label: "Item 4",  Value1: 0.2, Value2: 0.1, Value3: 0.2 });
        dataItems.push({ Label: "Item 5",  Value1: 0.1, Value2: 0.3, Value3: 0.4 });
        dataItems.push({ Label: "Item 6",  Value1: 0.2, Value2: 0.1, Value3: nan });
        dataItems.push({ Label: "Item 7",  Value1: 0.1, Value2: 0.3, Value3: 0.4 });
        dataItems.push({ Label: "Item 8",  Value1: 0.2, Value2: 0.1, Value3: 0.2 });
        dataItems.push({ Label: "Item 9",  Value1: 0.1, Value2: nan, Value3: 0.4 });
        dataItems.push({ Label: "Item 10", Value1: 0.2, Value2: 0.1, Value3: 0.2 });
        dataItems.push({ Label: "Item 11", Value1: 0.1, Value2: 0.3, Value3: 0.4 });
        dataItems.push({ Label: "Item 12", Value1: 0.2, Value2: 0.1, Value3: 0.4 });
        dataItems.push({ Label: "Item 13", Value1: nan, Value2: 0.3, Value3: 0.2 });
        dataItems.push({ Label: "Item 14", Value1: 0.2, Value2: 0.1, Value3: 0.4 });
        dataItems.push({ Label: "Item 15", Value1: 0.1, Value2: 0.3, Value3: 0.4 });

        // stacking data values if at least one of them is a number
        for (const item of dataItems) {

            if (this.isValid(item.Value1)) {
                item.StackedValue1 = item.Value1;
            }

            if (this.isValid(item.Value2)) {
                if (this.isValid(item.Value1)) {
                    item.StackedValue2 = item.Value2 + item.Value1;
                } else {
                    item.StackedValue2 = item.Value2;
                }
            }

            if (this.isValid(item.Value3)) {
                if (this.isValid(item.Value2)) {
                    if (this.isValid(item.Value1)) {
                        item.StackedValue3 = item.Value3 + item.Value2 + item.Value1;
                    } else {
                        item.StackedValue3 = item.Value3 + item.Value2;
                    }
                }else {
                    item.StackedValue3 = item.Value3;
                }
            }


        }

        // console.log(dataItems);
        this.data = dataItems;
    }

    isValid(value: number): boolean {
        if (value === undefined) return false;
        if (value === null) return false;
        if (isNaN(value)) return false;

        return isFinite(value);
    }

    public onStackedSeriesCreated(sender: any, args: IgxStackedSeriesCreatedEventArgs){
        console.log("EVENT FIRED!");
    }

    // @ViewChild("xAxis", { static: true })
    // private xAxis: IgxCategoryXAxisComponent
    // @ViewChild("yAxis", { static: true })
    // private yAxis: IgxNumericYAxisComponent
}

